google_sign_in_all_platforms_mobile library

Classes

GoogleSignInAllPlatformsInterface
The interface that implementations of google_sign_in_all_platforms must implement.
GoogleSignInAllPlatformsMobile
The Android implementation of GoogleSignInAllPlatformsInterface.
GoogleSignInCredentials
Object to store all necessary values regarding Google OAuth2.0 Credentials.
GoogleSignInParams
This class contains all the parameters that might be needed for performing the google sign in operation
GSIAPButtonConfig
Google Sign In Button Configurations
GSIAPButtonUiConfig
A class to configure the Google Sign-In Button for web.

Enums

GSIAPButtonLogoAlignment
The alignment of the Google logo. The default value is left. This attribute only applies to the standard button type.
GSIAPButtonShape
The button shape.
GSIAPButtonSize
The size of the button to be rendered.
GSIAPButtonText
The button text.
GSIAPButtonTheme
The theme of the button to be rendered.
GSIAPButtonType
The type of button to be rendered.

Properties

isDesktop bool
Whether the app is running on a desktop platform.
no setter
isDesktopWeb bool
Whether the web app is running on a desktop platform.
no setter
isMobile bool
Whether the app is running on a mobile platform.
no setter
isMobileWeb bool
Whether the web app is running on a mobile platform.
no setter
isWeb bool
Whether the app is running on the web.
no setter